@@ -120,6 +120,12 @@ def _default_dupe_key_error(integrity_error, match, engine_name,
     N columns - (IntegrityError) duplicate key value violates unique
                constraint "name_of_our_constraint"
 
+    mysql since 8.0.19:
+    1 column - (IntegrityError) (1062, "Duplicate entry 'value_of_c1' for key
+               'table_name.c1'")
+    N columns - (IntegrityError) (1062, "Duplicate entry 'values joined
+               with -' for key 'table_name.name_of_our_constraint'")
+
     mysql+mysqldb:
     1 column - (IntegrityError) (1062, "Duplicate entry 'value_of_c1' for key
                'c1'")
@@ -145,6 +151,9 @@ def _default_dupe_key_error(integrity_error, match, engine_name,
     if not columns.startswith(uniqbase):
         if engine_name == "postgresql":
             columns = [columns[columns.index("_") + 1:columns.rindex("_")]]
+        elif (engine_name == "mysql") and \
+             (uniqbase in str(columns.split("0")[:1])):
+            columns = columns.split("0")[1:]
         else:
             columns = [columns]
     else:
@@ -413,8 +422,7 @@ def _raise_for_remaining_DBAPIError(error, match, engine_name, is_disconnect):
     if is_disconnect:
         raise exception.DBConnectionError(error)
     else:
-        LOG.exception(
-            'DBAPIError exception wrapped from %s' % error)
+        LOG.warning('DBAPIError exception wrapped.', exc_info=True)
         raise exception.DBError(error)
 
 
@@ -425,9 +433,10 @@ def _raise_for_unicode_encode(error, match, engine_name, is_disconnect):
 
 @filters("*", Exception, r".*")
 def _raise_for_all_others(error, match, engine_name, is_disconnect):
-    LOG.exception('DB exception wrapped.')
+    LOG.warning('DB exception wrapped.', exc_info=True)
     raise exception.DBError(error)
 
+
 ROLLBACK_CAUSE_KEY = 'oslo.db.sp_rollback_cause'
 
 
@@ -517,13 +526,3 @@ def register_engine(engine):
     @event.listens_for(engine, "checkin")
     def pop_exc_checkin(dbapi_conn, connection_record):
         connection_record.info.pop(ROLLBACK_CAUSE_KEY, None)
-
-
-def handle_connect_error(engine):
-    """Connect to the engine, including handle_error handlers.
-
-    The compat library now builds this into the engine.connect()
-    system as per SQLAlchemy 1.0's behavior.
-
-    """
-    return engine.connect()
