@@ -24,7 +24,6 @@ import alembic
 import alembic.autogenerate
 import alembic.migration
 import pkg_resources as pkg
-import six
 import sqlalchemy
 import sqlalchemy.exc
 import sqlalchemy.sql.expression as expr
@@ -37,8 +36,7 @@ from oslo_db.sqlalchemy import utils
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class WalkVersionsMixin(object):
+class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
     """Test mixin to check upgrade and downgrade ability of migration.
 
     This is only suitable for testing of migrate_ migration scripts. An
@@ -274,8 +272,7 @@ class WalkVersionsMixin(object):
             raise
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ModelsMigrationsSync(object):
+class ModelsMigrationsSync(object, metaclass=abc.ABCMeta):
     """A helper class for comparison of DB migration scripts and models.
 
     It's intended to be inherited by test cases in target projects. They have
@@ -482,26 +479,6 @@ class ModelsMigrationsSync(object):
                 isinstance(meta_def.arg, expr.False_) and insp_def == "0"
             )
 
-        impl_type = meta_col.type
-        if isinstance(impl_type, types.Variant):
-            impl_type = impl_type.load_dialect_impl(bind.dialect)
-        if isinstance(impl_type, (sqlalchemy.Integer, sqlalchemy.BigInteger)):
-            if meta_def is None or insp_def is None:
-                return meta_def != insp_def
-            insp_def = insp_def.strip("'")
-            return meta_def.arg != insp_def
-
-    @_compare_server_default.dispatch_for('postgresql')
-    def _compare_server_default(bind, meta_col, insp_def, meta_def):
-        if isinstance(meta_col.type, sqlalchemy.Enum):
-            if meta_def is None or insp_def is None:
-                return meta_def != insp_def
-            return insp_def != "'%s'::%s" % (meta_def.arg, meta_col.type.name)
-        elif isinstance(meta_col.type, sqlalchemy.String):
-            if meta_def is None or insp_def is None:
-                return meta_def != insp_def
-            return insp_def != "'%s'::character varying" % meta_def.arg
-
     FKInfo = collections.namedtuple('fk_info', ['constrained_columns',
                                                 'referred_table',
                                                 'referred_columns'])
@@ -523,9 +500,9 @@ class ModelsMigrationsSync(object):
              [('drop_key',
                'testtbl_fk_check_fkey',
                'testtbl',
-               fk_info(constrained_columns=(u'fk_check',),
-                       referred_table=u'table',
-                       referred_columns=(u'fk_check',)))]
+               fk_info(constrained_columns=('fk_check',),
+                       referred_table='table',
+                       referred_columns=('fk_check',)))]
 
         DEPRECATED: this function is deprecated and will be removed from
         oslo.db in a few releases. Alembic autogenerate.compare_metadata()
