@@ -17,14 +17,8 @@
 #    under the License.
 
 import collections
-# TODO(smcginnis) update this once six has support for collections.abc
-# (https://github.com/benjaminp/six/pull/241) or clean up once we drop py2.7.
-try:
-    from collections.abc import Iterable
-except ImportError:
-    from collections import Iterable
+from collections import abc
 import contextlib
-import inspect as pyinspect
 import itertools
 import logging
 import re
@@ -32,7 +26,6 @@ import re
 from alembic.migration import MigrationContext
 from alembic.operations import Operations
 from oslo_utils import timeutils
-import six
 import sqlalchemy
 from sqlalchemy import Boolean
 from sqlalchemy import CheckConstraint
@@ -286,7 +279,7 @@ def paginate_query(query, model, limit, sort_keys, marker=None,
 def to_list(x, default=None):
     if x is None:
         return default
-    if not isinstance(x, Iterable) or isinstance(x, six.string_types):
+    if not isinstance(x, abc.Iterable) or isinstance(x, str):
         return [x]
     elif isinstance(x, list):
         return x
@@ -941,7 +934,7 @@ class DialectFunctionDispatcher(object):
     def _url_from_target(self, target):
         if isinstance(target, Connectable):
             return target.engine.url
-        elif isinstance(target, six.string_types):
+        elif isinstance(target, str):
             if "://" not in target:
                 target_url = sa_url.make_url("%s://" % target)
             else:
@@ -1032,6 +1025,7 @@ class DialectMultiFunctionDispatcher(DialectFunctionDispatcher):
                     "Return value not allowed for "
                     "multiple filtered function")
 
+
 dispatch_for_dialect = DialectFunctionDispatcher.dispatch_for_dialect
 
 
@@ -1189,25 +1183,6 @@ def suspend_fk_constraints_for_col_alter(
                 )
 
 
-def getargspec(fn):
-    """Inspects a function for its argspec.
-
-    This is to handle a difference between py2/3. The Python 2.x getargspec
-    call is deprecated in Python 3.x, with the suggestion to use the signature
-    call instead.
-
-    To keep compatibility with the results, while avoiding deprecation
-    warnings, this instead will use the getfullargspec instead.
-
-    :param fn: The function to inspect.
-    :returns: The argspec for the function.
-    """
-    if hasattr(pyinspect, 'getfullargspec'):
-        return pyinspect.getfullargspec(fn)
-
-    return pyinspect.getargspec(fn)
-
-
 class NonCommittingConnectable(object):
     """A ``Connectable`` substitute which rolls all operations back.
 
